@@ -687,9 +687,7 @@ class Canvas(QtWidgets.QWidget):
         if self.double_click != "close":
             return
 
-        if (
-            self.createMode == "polygon" and self.canCloseShape()
-        ) or self.createMode in ["ai_polygon", "ai_mask"]:
+        if self.canCloseShape():
             self.finalise()
 
     def selectShapes(self, shapes):
@@ -1134,6 +1132,7 @@ class Canvas(QtWidgets.QWidget):
         self.pixmap = QtGui.QPixmap()
         self.shapes = []
         self.shapesBackups = []
+        self.selectedShapes = []
         self.update()
 
 
